==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/architecture/expression/impl/ParenthesizedExpressionSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.ParenthesizedExpression;
import io.ciera.tool.sql.architecture.expression.ParenthesizedExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;

import java.util.Arrays;
import java.util.List;


public class ParenthesizedExpressionSetImpl extends InstanceSet<ParenthesizedExpressionSet,ParenthesizedExpression> implements ParenthesizedExpressionSet {

    // attributes
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( ParenthesizedExpression parenthesizedexpression : this ) parenthesizedexpression.setBlock_number( ref_block_number );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( ParenthesizedExpression parenthesizedexpression : this ) parenthesizedexpression.setParent_package( ref_parent_package );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( ParenthesizedExpression parenthesizedexpression : this ) parenthesizedexpression.setStatement_number( ref_statement_number );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( ParenthesizedExpression parenthesizedexpression : this ) parenthesizedexpression.setExpression_number( ref_expression_number );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( ParenthesizedExpression parenthesizedexpression : this ) parenthesizedexpression.setParent_name( ref_parent_name );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( ParenthesizedExpression parenthesizedexpression : this ) parenthesizedexpression.setBody_name( ref_body_name );
    }
    @Override
    public void setBase_expression_number( String ref_base_expression_number ) throws XtumlException {
        for ( ParenthesizedExpression parenthesizedexpression : this ) parenthesizedexpression.setBase_expression_number( ref_base_expression_number );
    }


    // selections
    @Override
    public ExpressionSet R776_is_a_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( ParenthesizedExpression parenthesizedexpression : this ) expressionset.add( parenthesizedexpression.R776_is_a_Expression() );
        return expressionset;
    }
    @Override
    public ExpressionSet R784_parenthesizes_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( ParenthesizedExpression parenthesizedexpression : this ) expressionset.add( parenthesizedexpression.R784_parenthesizes_Expression() );
        return expressionset;
    }


    @Override
    public ParenthesizedExpression nullElement() {
        return ParenthesizedExpressionImpl.EMPTY_PARENTHESIZEDEXPRESSION;
    }

    @Override
    public ParenthesizedExpressionSet emptySet() {
      return new ParenthesizedExpressionSetImpl();
    }

    @Override
    public ParenthesizedExpressionSet value() {
        return this;
    }

    @Override
    public List<ParenthesizedExpression> elements() {
        return Arrays.asList(toArray(new ParenthesizedExpression[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/architecture/expression/impl/ParenthesizedExpressionSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.ParenthesizedExpression;
import io.ciera.tool.sql.architecture.expression.ParenthesizedExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ParenthesizedExpressionSetImpl extends InstanceSet<ParenthesizedExpressionSet,ParenthesizedExpression> implements ParenthesizedExpressionSet {

    public ParenthesizedExpressionSetImpl() {
    }

    public ParenthesizedExpressionSetImpl(Comparator<? super ParenthesizedExpression> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setBase_expression_number( String ref_base_expression_number ) throws XtumlException {
        for ( ParenthesizedExpression parenthesizedexpression : this ) parenthesizedexpression.setBase_expression_number( ref_base_expression_number );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( ParenthesizedExpression parenthesizedexpression : this ) parenthesizedexpression.setBlock_number( ref_block_number );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( ParenthesizedExpression parenthesizedexpression : this ) parenthesizedexpression.setParent_name( ref_parent_name );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( ParenthesizedExpression parenthesizedexpression : this ) parenthesizedexpression.setParent_package( ref_parent_package );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( ParenthesizedExpression parenthesizedexpression : this ) parenthesizedexpression.setBody_name( ref_body_name );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( ParenthesizedExpression parenthesizedexpression : this ) parenthesizedexpression.setExpression_number( ref_expression_number );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( ParenthesizedExpression parenthesizedexpression : this ) parenthesizedexpression.setStatement_number( ref_statement_number );
    }


    // selections
    @Override
    public ExpressionSet R776_is_a_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( ParenthesizedExpression parenthesizedexpression : this ) expressionset.add( parenthesizedexpression.R776_is_a_Expression() );
        return expressionset;
    }
    @Override
    public ExpressionSet R784_parenthesizes_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( ParenthesizedExpression parenthesizedexpression : this ) expressionset.add( parenthesizedexpression.R784_parenthesizes_Expression() );
        return expressionset;
    }


    @Override
    public ParenthesizedExpression nullElement() {
        return ParenthesizedExpressionImpl.EMPTY_PARENTHESIZEDEXPRESSION;
    }

    @Override
    public ParenthesizedExpressionSet emptySet() {
      return new ParenthesizedExpressionSetImpl();
    }

    @Override
    public ParenthesizedExpressionSet emptySet(Comparator<? super ParenthesizedExpression> comp) {
      return new ParenthesizedExpressionSetImpl(comp);
    }

    @Override
    public ParenthesizedExpressionSet value() {
        return this;
    }

    @Override
    public List<ParenthesizedExpression> elements() {
        return Arrays.asList(toArray(new ParenthesizedExpression[0]));
    }

}
